<?php
/**
 * Strata Three functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Strata_Three
 */


if ( ! function_exists( 's3_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function s3_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Strata Three, use a find and replace
	 * to change 's3' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 's3', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );


	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary Menu', 's3' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

}
endif; // s3_setup
add_action( 'after_setup_theme', 's3_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function s3_content_width() {
	$GLOBALS['content_width'] = apply_filters( 's3_content_width', 945 );
}
add_action( 'after_setup_theme', 's3_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function s3_widgets_init() {
	# Create four (8) sidebars
	$sidebar_count = 8;
	$args = array (
		'name'          => esc_html__( 'Sidebar: %d', 's3' ),
		'id'            => 'sidebar',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="h5">',
		'after_title'   => '</h2>',
	);
	register_sidebars($sidebar_count, $args);
	# Note: Sidebars are name as such: sidebar, sidebar-2, sidebar-3, sidebar-4, etc.
	# (Personal note to the above: this vexes me.)
}
add_action( 'widgets_init', 's3_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function s3_scripts() {
	$wp_theme   = wp_get_theme( 's3' );
	$wp_version = $wp_theme->get( 'Version' );
	
	# Styles
	wp_enqueue_style( 'style-webtype',           'https://use.typekit.net/qwg1fji.css' );
	wp_enqueue_style( 'style-bootstrap',         get_template_directory_uri() . '/s3.3/css/bootstrap.min.css' );
	wp_enqueue_style( 'style-strata',            get_template_directory_uri() . '/s3.3/css/strata.min.css', 'style-bootstrap', $wp_version);
	wp_enqueue_style( 'style-strata-extend',     get_template_directory_uri() . '/s3.3/css/strata-extend.min.css', 'style-extend', $wp_version);
	wp_enqueue_style( 'style-theme',             get_stylesheet_uri() );
	wp_enqueue_style( 'style-print',             get_template_directory_uri() . '/s3.3/css/print.css', 'style-theme', $wp_version, 'print' );
	wp_enqueue_style( 'style-fontawesome',       'https://use.fontawesome.com/releases/v5.0.13/css/all.css' );

	# Scripts
	wp_enqueue_script( 'script-jquery',          'https://code.jquery.com/jquery-2.2.4.min.js', array(), $wp_version, true );
	wp_enqueue_script( 'script-jquery-ui',       'https://code.jquery.com/ui/1.12.1/jquery-ui.min.js', array(), $wp_version, true );
	wp_enqueue_script( 'script-bootstrap',       get_template_directory_uri() . '/s3.3/js/bootstrap.min.js', array(), $wp_version, true );
	wp_enqueue_script( 'script-strata',          get_template_directory_uri() . '/s3.3/js/strata.min.js', array(), $wp_version, true );
	wp_enqueue_script( 'script-strata-extend',   get_template_directory_uri() . '/s3.3/js/strata-extend.min.js', array(), $wp_version, true );
	wp_enqueue_script( 'script-navigation',      get_template_directory_uri() . '/js/functions.js', array( 'jquery' ), '20120206', true );

	# Gallery: Frecso
	if (_SITE_GALLERY_TYPE == 'fresco') {
		wp_enqueue_script( 'script-fresco',          get_template_directory_uri() . '/inc/lib/fresco/fresco.js', array(), $wp_version, true );
		wp_enqueue_style(  'style-fresco',           get_template_directory_uri() . '/inc/lib/fresco/fresco.css', 'style-theme', $wp_version);
	}

	wp_enqueue_script( 'fo-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), $wp_version, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

}
add_action( 'wp_enqueue_scripts', 's3_scripts' );

# Custom template tags for this theme.
require get_template_directory() . '/inc/template-tags.php';

# Customizer additions.
#require get_template_directory() . '/inc/customizer.php';

# Load Jetpack compatibility file.
require get_template_directory() . '/inc/jetpack.php';


# Remove iframe from RSS feed
function rss_noiframe($content) {
    $content = preg_replace( '/<iframe(.*)\/iframe>/is', '', $content );

    return $content;
}
add_filter('the_excerpt_rss', 'rss_noiframe');
add_filter('the_content_feed', 'rss_noiframe');



# Remove iframe's frameborder property
function wpse_308247_remove_frameborder( $html, $url ) {
    // If the URL to be embedded is from YouTube.
    if ( strpos( $url, 'youtube.com' ) !== false ) {
        // Replace the frameborder attribute with an empty string.
        $html = str_replace( 'frameborder="0"', '', $html );
    }

    return $html;
}
add_filter( 'embed_oembed_html', 'wpse_308247_remove_frameborder', 10, 2 );



